"start_time": <%= @start_time.to_i %>,
"start_memory": <%= @start_memory.to_i %>,
"target_url": <%= @url.to_s.to_json %>,
"target_ip": <%= @ip.to_s.to_json %>,
"effective_url": <%= @effective_url.to_s.to_json %>,